@@ -1,8 +1,9 @@
-from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port,logwarehouse
+from aishu import setting
+from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port
+from aishu.datafaker.profession.entity import zx
 from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
 from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
 
-
 def filed(key,inquire=[]):
     """
     :param key:
@@ -67,21 +68,21 @@ def filed(key,inquire=[]):
         'DeleteAlertRuleNamesID': ParaDateAnyRobotServer(key).getDeleteAlertRuleNamesId,
         'UpdateTimeID': ParaDateFiledServer().getUpdateTime,
         'UtcStartID': ParaDateFiledServer().getUtcStartTime,
-        'UtcEndID': ParaDateFiledServer().getUtcEndTime
-        # 'LogwareHouse': ParaDateAnyRobotServer(key).getLogwareHouse,
-        # 'dataType': ParaDateAnyRobotServer(key).getdataType,
-        # 'indexID': ParaDateAnyRobotServer(key).getindexID,
-        # 'indexName': ParaDateAnyRobotServer(key).getindexName,
-        # 'StreamId': ParaDateAnyRobotServer(key).getStreamId,
-        # 'LogGroupIdPare': ParaDateAnyRobotServer(key).getLogGroupIdPare,
-        # 'UserID': ParaDateAnyRobotServer(key).getUserID,
-        # 'RoleId': ParaDateAnyRobotServer(key).getRoleId,
-        # 'tagGroupID': ParaDateAnyRobotServer(key).gettagGroupID,
-        # 'tagID': ParaDateAnyRobotServer(key).gettagID,
+        'UtcEndID': ParaDateFiledServer().getUtcEndTime,
+        's_id': zx.search().createSearchId
     }
 
     switcher = SERVICE_KPI_
     if switcher.get(key) is not None:
         return switcher[key]()
     else:
-        return False
\ No newline at end of file
+        return False
+
+if __name__ == '__main__':
+    setting.host = ""
+    setting.database = 'AnyRobot'
+    setting.password = ''
+    setting.port = 30006
+    setting.user = ''
+    date = filed("UpdateTimeID")
+    print(date)
\ No newline at end of file
